export class BaseRepository {
    model;
    constructor(model) {
        this.model = model;
    }
    findOne = async (filter = {}) => {
        return await this.model.findOne({
            where: filter.where,
            include: filter.include || undefined,
        });
    };
    findAll = async (filter = {}) => {
        const entities = await this.model.findAll({
            where: filter.where || undefined,
            include: filter.include || undefined,
        });
        return entities;
    };
    create = async (data, includeModels = [], transaction) => {
        return await this.model.create(data, {
            include: includeModels,
            transaction,
        });
    };
    bulkCreate = async (data, includeModels = []) => {
        return await this.model.bulkCreate(data, {
            include: includeModels,
        });
    };
    update = async (id, data) => {
        Object.keys(data).forEach((key) => {
            const typedKey = key;
            if (data[typedKey] === undefined) {
                data[typedKey] = null;
            }
        });
        await this.model.update(data, {
            where: { id },
        });
    };
    delete = async (ids) => {
        await this.model.destroy({
            where: { id: ids },
        });
    };
    paginate = async (page = 1, limit = 10, filter = {}) => {
        const { count: total, rows: data } = await this.model.findAndCountAll({
            where: filter.where || undefined,
            include: filter.include || undefined,
            offset: (page - 1) * limit,
            limit,
            order: filter.order,
            distinct: true,
        });
        return {
            data,
            total,
            page,
            limit,
        };
    };
}
//# sourceMappingURL=base.repository.js.map