import { NotFoundException } from "../dtos/error/base.error.js";
import { getResponseMessage } from "../helpers/language.helper.js";
export class BaseLogic {
    baseRepo;
    modelName;
    constructor(baseRepo, modelName) {
        this.baseRepo = baseRepo;
        this.modelName = modelName;
    }
    findOne = async (filter = {}) => {
        const entity = await this.baseRepo.findOne(filter);
        if (!entity)
            throw new NotFoundException(getResponseMessage("NOT_FOUND", this.modelName));
        return entity;
    };
    findAll = async (filter = {}) => {
        const entities = await this.baseRepo.findAll(filter);
        return entities;
    };
    create = async (data, includeModels = [], transaction) => {
        return await this.baseRepo.create(data, includeModels, transaction);
    };
    bulkCreate = async (data, includeModels = []) => await this.baseRepo.bulkCreate(data, includeModels);
    update = async (id, data) => await this.baseRepo.update(id, data);
    delete = async (ids) => await this.baseRepo.delete(ids);
    paginate = async (page = 1, limit = 10, filter = {}) => await this.baseRepo.paginate(page, limit, filter);
}
//# sourceMappingURL=base.service.js.map